@@ -268,63 +268,3 @@ restore_editable_from_undo_snapshot_callback (GObject *target, gpointer callback
 	/* Reset the registered flag so we get a new item for future editing. */
 	data->undo_registered = FALSE;
 }
-
-
-/* editable_set_undo_key
- *
- * Allow the use of ctrl-z from within widget.
- */
-
-/* Undo is disabled until we have a better implementation.
- * Both here and in nautilus-shell-ui.xml.
- */
-
-/* FIXME bugzilla.gnome.org 43515: Undo doesn't work */
-#ifdef UNDO_ENABLED
-
-static gboolean
-editable_key_press_event (GtkEditable *editable, GdkEventKey *event, gpointer user_data)
-{	
-	switch (event->keyval) {
-	/* Undo */
-	case 'z':
-		if ((event->state & GDK_CONTROL_MASK) != 0) {
-			nautilus_undo (GTK_OBJECT (editable));
-			return TRUE;
-		}
-		break;
-		
-	default:
-		break;
-	}
-
-	return FALSE;
-}
-
-#endif
-
-/* editable_set_undo_key
- *
- * Allow the use of ctrl-z from within widget.  This should only be 
- * set if there is no menu bar to use to undo the widget.
- */
- 
-void 
-nautilus_undo_editable_set_undo_key (GtkEditable *editable, gboolean value)
-{
-/* FIXME bugzilla.gnome.org 43515: Undo doesn't work */
-#ifdef UNDO_ENABLED
-	if (value) {
-		/* Connect to entry signals */
-		g_signal_connect (editable, "key_press_event",
-				  G_CALLBACK (editable_key_press_event), NULL);
-	} else {
-		/* FIXME bugzilla.gnome.org 45092: Warns if the handler
-		 * is not already connected. We could use object data
-		 * to prevent that little problem.
-		 */
-		gtk_signal_disconnect_by_func (editable, 
-					       G_CALLBACK (editable_key_press_event), NULL);
-	}
-#endif
-}
