@@ -73,6 +73,8 @@ struct _NautilusConnectServerDialogDetails {
 	gboolean last_password_set;
 	gulong password_sensitive_id;
 	gboolean should_destroy;
+
+	GCancellable *mount_cancellable;
 };
 
 G_DEFINE_TYPE (NautilusConnectServerDialog, nautilus_connect_server_dialog,
@@ -169,7 +171,7 @@ connect_dialog_set_connecting (NautilusConnectServerDialog *dialog)
 
 	content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (dialog->details->info_bar));
 
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_container_add (GTK_CONTAINER (content_area), hbox);
 	gtk_widget_show (hbox);
 
@@ -198,7 +200,7 @@ connect_dialog_gvfs_error (NautilusConnectServerDialog *dialog)
 
 	content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (dialog->details->info_bar));
 
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_container_add (GTK_CONTAINER (content_area), hbox);
 	gtk_widget_show (hbox);
 
@@ -310,7 +312,7 @@ connect_dialog_set_info_bar_error (NautilusConnectServerDialog *dialog,
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_widget_show (dialog->details->info_bar);
 
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start (GTK_BOX (content_area), hbox, FALSE, FALSE, 6);
 	gtk_widget_show (hbox);
 
@@ -385,7 +387,7 @@ connect_dialog_request_additional_details (NautilusConnectServerDialog *self,
 
 	content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (self->details->info_bar));
 
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_box_pack_start (GTK_BOX (content_area), hbox, FALSE, FALSE, 6);
 	gtk_widget_show (hbox);
 
@@ -486,6 +488,8 @@ mount_enclosing_ready_cb (GObject *source,
 		}
 	}
 
+	g_clear_object (&dialog->details->mount_cancellable);
+
 	if (error != NULL) {
 		g_error_free (error);
 	}
@@ -497,9 +501,11 @@ connect_dialog_present_uri_async (NautilusConnectServerDialog *self,
 {
 	GMountOperation *op;
 
+	self->details->mount_cancellable = g_cancellable_new ();
+
 	op = nautilus_connect_server_operation_new (self);
 	g_file_mount_enclosing_volume (location,
-				       0, op, NULL,
+				       0, op, self->details->mount_cancellable,
 				       mount_enclosing_ready_cb, self);
 	g_object_unref (op);
 }
@@ -513,6 +519,7 @@ connect_dialog_connect_to_server (NautilusConnectServerDialog *dialog)
 	GtkTreeIter iter;
 	char *user, *initial_path, *server, *folder, *domain, *port_str;
 	char *t, *join, *uri;
+	char *temp, *stripped_server;
 	double port;
 
 	/* Get our method info */
@@ -524,6 +531,14 @@ connect_dialog_connect_to_server (NautilusConnectServerDialog *dialog)
 
 	server = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->server_entry), 0, -1);
 
+	temp = g_strconcat (meth->scheme, "://", NULL);
+	if (g_str_has_prefix (server, temp)) {
+		stripped_server = g_strdup (server + strlen (temp));
+		g_free (server);
+		server = stripped_server;
+	}
+	g_free (temp);
+
 	user = NULL;
 	initial_path = g_strdup ("");
 	domain = NULL;
@@ -627,7 +642,12 @@ connect_to_server_or_finish_fill (NautilusConnectServerDialog *dialog)
 static gboolean
 connect_dialog_abort_mount_operation (NautilusConnectServerDialog *dialog)
 {
-	if (dialog->details->fill_details_res != NULL) {
+	gboolean retval = FALSE;
+
+	if (dialog->details->mount_cancellable != NULL) {
+		g_cancellable_cancel (dialog->details->mount_cancellable);
+		retval = TRUE;
+	} else if (dialog->details->fill_details_res != NULL) {
 		g_simple_async_result_set_op_res_gboolean (dialog->details->fill_details_res, FALSE);
 		g_simple_async_result_complete (dialog->details->fill_details_res);
 
@@ -639,10 +659,10 @@ connect_dialog_abort_mount_operation (NautilusConnectServerDialog *dialog)
 			dialog->details->fill_operation = NULL;
 		}
 
-		return TRUE;
+		retval = TRUE;
 	}
 
-	return FALSE;
+	return retval;
 }
 
 static void
@@ -650,6 +670,7 @@ connect_dialog_destroy (NautilusConnectServerDialog *dialog)
 {
 	if (connect_dialog_abort_mount_operation (dialog)) {
 		dialog->details->should_destroy = TRUE;
+		gtk_widget_hide (GTK_WIDGET (dialog));
 	} else {
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 	}
@@ -868,7 +889,7 @@ nautilus_connect_server_dialog_init (NautilusConnectServerDialog *dialog)
 	gtk_size_group_add_widget (dialog->details->labels_size_group, label);
 	gtk_widget_show (label);
 
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_widget_show (hbox);
 	gtk_table_attach (GTK_TABLE (table), hbox,
 			  1, 2,
@@ -1196,6 +1217,15 @@ nautilus_connect_server_dialog_fill_details_async (NautilusConnectServerDialog *
 	const gchar *str;
 	GAskPasswordFlags set_flags;
 
+	if (g_cancellable_is_cancelled (self->details->mount_cancellable)) {
+		g_simple_async_report_error_in_idle (G_OBJECT (self),
+						     callback, user_data,
+						     G_IO_ERROR, G_IO_ERROR_CANCELLED,
+						     "%s", _("Operation cancelled"));
+
+		return;
+	}
+
 	fill_details_res = g_simple_async_result_new (G_OBJECT (self), callback, user_data,
 						      nautilus_connect_server_dialog_fill_details_async);
 
