@@ -80,6 +80,7 @@ typedef struct {
 
 	GtkWidget *popup_menu;
 	GtkWidget *popup_menu_open_in_new_tab_item;
+	GtkWidget *popup_menu_add_shortcut_item;
 	GtkWidget *popup_menu_remove_item;
 	GtkWidget *popup_menu_rename_item;
 	GtkWidget *popup_menu_separator_item;
@@ -675,19 +676,6 @@ update_places (NautilusPlacesSidebar *sidebar)
 		g_free (desktop_path);
 	}
 
-	/* file system root */
- 	mount_uri = "file:///"; /* No need to strdup */
-	icon = g_themed_icon_new (NAUTILUS_ICON_FILESYSTEM);
-	last_iter = add_place (sidebar, PLACES_BUILT_IN,
-			       SECTION_COMPUTER,
-			       _("File System"), icon,
-			       mount_uri, NULL, NULL, NULL, 0,
-			       _("Open the contents of the File System"));
-	g_object_unref (icon);
-	compare_for_selection (sidebar,
-			       location, mount_uri, last_uri,
-			       &last_iter, &select_path);
-
 	
 	/* XDG directories */
 	for (index = 0; index < G_USER_N_DIRECTORIES; index++) {
@@ -772,6 +760,19 @@ update_places (NautilusPlacesSidebar *sidebar)
 	}
 	g_list_free (mounts);
 
+	/* file system root */
+ 	mount_uri = "file:///"; /* No need to strdup */
+	icon = g_themed_icon_new (NAUTILUS_ICON_FILESYSTEM);
+	last_iter = add_place (sidebar, PLACES_BUILT_IN,
+			       SECTION_COMPUTER,
+			       _("File System"), icon,
+			       mount_uri, NULL, NULL, NULL, 0,
+			       _("Open the contents of the File System"));
+	g_object_unref (icon);
+	compare_for_selection (sidebar,
+			       location, mount_uri, last_uri,
+			       &last_iter, &select_path);
+
 	mount_uri = "trash:///"; /* No need to strdup */
 	icon = nautilus_trash_monitor_get_icon ();
 	last_iter = add_place (sidebar, PLACES_BUILT_IN,
@@ -1537,6 +1538,7 @@ bookmarks_popup_menu_detach_cb (GtkWidget *attach_widget,
 	g_assert (NAUTILUS_IS_PLACES_SIDEBAR (sidebar));
 	
 	sidebar->popup_menu = NULL;
+	sidebar->popup_menu_add_shortcut_item = NULL;
 	sidebar->popup_menu_remove_item = NULL;
 	sidebar->popup_menu_rename_item = NULL;
 	sidebar->popup_menu_separator_item = NULL;
@@ -1642,6 +1644,8 @@ bookmarks_check_popup_sensitivity (NautilusPlacesSidebar *sidebar)
 				    -1);
 	}
 
+	gtk_widget_set_visible (sidebar->popup_menu_add_shortcut_item, (type == PLACES_MOUNTED_VOLUME));
+
 	gtk_widget_set_sensitive (sidebar->popup_menu_remove_item, (type == PLACES_BOOKMARK));
 	gtk_widget_set_sensitive (sidebar->popup_menu_rename_item, (type == PLACES_BOOKMARK));
 	gtk_widget_set_sensitive (sidebar->popup_menu_empty_trash_item, !nautilus_trash_monitor_is_empty ());
@@ -1730,17 +1734,12 @@ volume_mounted_cb (GVolume *volume,
 				nautilus_window_slot_open_location (sidebar->go_to_after_mount_slot, location,
 								    sidebar->go_to_after_mount_flags, NULL);
 			} else {
-				NautilusApplication *app;
 				NautilusWindow *new, *cur;
 
 				cur = NAUTILUS_WINDOW (sidebar->window);
-				app = nautilus_application_dup_singleton ();
-				new = nautilus_application_create_window (app,
-									  NULL,
+				new = nautilus_application_create_window (nautilus_application_get_singleton (),
 									  gtk_window_get_screen (GTK_WINDOW (cur)));
 				nautilus_window_go_to (new, location);
-
-				g_object_unref (app);
 			}
 		}
 
@@ -1803,16 +1802,11 @@ open_selected_bookmark (NautilusPlacesSidebar *sidebar,
 							    flags, NULL);
 		} else {
 			NautilusWindow *cur, *new;
-			NautilusApplication *app;
 			
 			cur = NAUTILUS_WINDOW (sidebar->window);
-			app = nautilus_application_dup_singleton ();
-			new = nautilus_application_create_window (app,
-								  NULL,
+			new = nautilus_application_create_window (nautilus_application_get_singleton (),
 								  gtk_window_get_screen (GTK_WINDOW (cur)));
 			nautilus_window_go_to (new, location);
-
-			g_object_unref (app);
 		}
 		g_object_unref (location);
 		g_free (uri);
@@ -1896,6 +1890,45 @@ open_shortcut_in_new_tab_cb (GtkMenuItem	      *item,
 	open_shortcut_from_menu (sidebar, NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB);
 }
 
+/* Add bookmark for the selected item */
+static void
+add_bookmark (NautilusPlacesSidebar *sidebar)
+{
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	char *uri;
+	GFile *location;
+	NautilusBookmark *bookmark;
+
+	model = gtk_tree_view_get_model (sidebar->tree_view);
+
+	if (get_selected_iter (sidebar, &iter)) {
+		gtk_tree_model_get (model, &iter, PLACES_SIDEBAR_COLUMN_URI, &uri, -1);
+
+		if (uri == NULL) {
+			return;
+		}
+
+		location = g_file_new_for_uri (uri);
+		bookmark = nautilus_bookmark_new (location, NULL, NULL);
+
+		if (!nautilus_bookmark_list_contains (sidebar->bookmarks, bookmark)) {
+			nautilus_bookmark_list_append (sidebar->bookmarks, bookmark);
+		}
+
+		g_object_unref (location);
+		g_object_unref (bookmark);
+		g_free (uri);
+	}
+}
+
+static void
+add_shortcut_cb (GtkMenuItem           *item,
+		 NautilusPlacesSidebar *sidebar)
+{
+	add_bookmark (sidebar);
+}
+
 /* Rename the selected bookmark */
 static void
 rename_selected_bookmark (NautilusPlacesSidebar *sidebar)
@@ -2577,6 +2610,12 @@ bookmarks_build_popup_menu (NautilusPlacesSidebar *sidebar)
 
 	eel_gtk_menu_append_separator (GTK_MENU (sidebar->popup_menu));
 
+	item = gtk_menu_item_new_with_mnemonic (_("_Add Bookmark"));
+	sidebar->popup_menu_add_shortcut_item = item;
+	g_signal_connect (item, "activate",
+			  G_CALLBACK (add_shortcut_cb), sidebar);
+	gtk_menu_shell_append (GTK_MENU_SHELL (sidebar->popup_menu), item);
+
 	item = gtk_image_menu_item_new_with_label (_("Remove"));
 	sidebar->popup_menu_remove_item = item;
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item),
